import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { CreateEventRuleRequest, CreateEventRuleResponse } from "../models/models_0";
import { NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../NotificationsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link CreateEventRuleCommand}.
 */
export interface CreateEventRuleCommandInput extends CreateEventRuleRequest {
}
/**
 * @public
 *
 * The output of {@link CreateEventRuleCommand}.
 */
export interface CreateEventRuleCommandOutput extends CreateEventRuleResponse, __MetadataBearer {
}
declare const CreateEventRuleCommand_base: {
    new (input: CreateEventRuleCommandInput): import("@smithy/smithy-client").CommandImpl<CreateEventRuleCommandInput, CreateEventRuleCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: CreateEventRuleCommandInput): import("@smithy/smithy-client").CommandImpl<CreateEventRuleCommandInput, CreateEventRuleCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Creates an <a href="https://docs.aws.amazon.com/notifications/latest/userguide/glossary.html">EventRule</a> that is associated with a specified Notification Configuration.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { NotificationsClient, CreateEventRuleCommand } from "@aws-sdk/client-notifications"; // ES Modules import
 * // const { NotificationsClient, CreateEventRuleCommand } = require("@aws-sdk/client-notifications"); // CommonJS import
 * const client = new NotificationsClient(config);
 * const input = { // CreateEventRuleRequest
 *   notificationConfigurationArn: "STRING_VALUE", // required
 *   source: "STRING_VALUE", // required
 *   eventType: "STRING_VALUE", // required
 *   eventPattern: "STRING_VALUE",
 *   regions: [ // Regions // required
 *     "STRING_VALUE",
 *   ],
 * };
 * const command = new CreateEventRuleCommand(input);
 * const response = await client.send(command);
 * // { // CreateEventRuleResponse
 * //   arn: "STRING_VALUE", // required
 * //   notificationConfigurationArn: "STRING_VALUE", // required
 * //   statusSummaryByRegion: { // StatusSummaryByRegion // required
 * //     "<keys>": { // EventRuleStatusSummary
 * //       status: "STRING_VALUE", // required
 * //       reason: "STRING_VALUE", // required
 * //     },
 * //   },
 * // };
 *
 * ```
 *
 * @param CreateEventRuleCommandInput - {@link CreateEventRuleCommandInput}
 * @returns {@link CreateEventRuleCommandOutput}
 * @see {@link CreateEventRuleCommandInput} for command's `input` shape.
 * @see {@link CreateEventRuleCommandOutput} for command's `response` shape.
 * @see {@link NotificationsClientResolvedConfig | config} for NotificationsClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>User does not have sufficient access to perform this action.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>Updating or deleting a resource can cause an inconsistent state.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Unexpected error during processing of request.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Request references a resource which does not exist. </p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>Request would cause a service quota to be exceeded.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Request was denied due to request throttling. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>This exception is thrown when the notification event fails validation.</p>
 *
 * @throws {@link NotificationsServiceException}
 * <p>Base exception class for all service exceptions from Notifications service.</p>
 *
 * @public
 */
export declare class CreateEventRuleCommand extends CreateEventRuleCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: CreateEventRuleRequest;
            output: CreateEventRuleResponse;
        };
        sdk: {
            input: CreateEventRuleCommandInput;
            output: CreateEventRuleCommandOutput;
        };
    };
}
