import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListEventRulesRequest, ListEventRulesResponse } from "../models/models_0";
import { NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../NotificationsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListEventRulesCommand}.
 */
export interface ListEventRulesCommandInput extends ListEventRulesRequest {
}
/**
 * @public
 *
 * The output of {@link ListEventRulesCommand}.
 */
export interface ListEventRulesCommandOutput extends ListEventRulesResponse, __MetadataBearer {
}
declare const ListEventRulesCommand_base: {
    new (input: ListEventRulesCommandInput): import("@smithy/smithy-client").CommandImpl<ListEventRulesCommandInput, ListEventRulesCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ListEventRulesCommandInput): import("@smithy/smithy-client").CommandImpl<ListEventRulesCommandInput, ListEventRulesCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a list of EventRules according to specified filters, in reverse chronological order (newest first).</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { NotificationsClient, ListEventRulesCommand } from "@aws-sdk/client-notifications"; // ES Modules import
 * // const { NotificationsClient, ListEventRulesCommand } = require("@aws-sdk/client-notifications"); // CommonJS import
 * const client = new NotificationsClient(config);
 * const input = { // ListEventRulesRequest
 *   notificationConfigurationArn: "STRING_VALUE", // required
 *   maxResults: Number("int"),
 *   nextToken: "STRING_VALUE",
 * };
 * const command = new ListEventRulesCommand(input);
 * const response = await client.send(command);
 * // { // ListEventRulesResponse
 * //   nextToken: "STRING_VALUE",
 * //   eventRules: [ // EventRules // required
 * //     { // EventRuleStructure
 * //       arn: "STRING_VALUE", // required
 * //       notificationConfigurationArn: "STRING_VALUE", // required
 * //       creationTime: new Date("TIMESTAMP"), // required
 * //       source: "STRING_VALUE", // required
 * //       eventType: "STRING_VALUE", // required
 * //       eventPattern: "STRING_VALUE", // required
 * //       regions: [ // Regions // required
 * //         "STRING_VALUE",
 * //       ],
 * //       managedRules: [ // ManagedRuleArns // required
 * //         "STRING_VALUE",
 * //       ],
 * //       statusSummaryByRegion: { // StatusSummaryByRegion // required
 * //         "<keys>": { // EventRuleStatusSummary
 * //           status: "STRING_VALUE", // required
 * //           reason: "STRING_VALUE", // required
 * //         },
 * //       },
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListEventRulesCommandInput - {@link ListEventRulesCommandInput}
 * @returns {@link ListEventRulesCommandOutput}
 * @see {@link ListEventRulesCommandInput} for command's `input` shape.
 * @see {@link ListEventRulesCommandOutput} for command's `response` shape.
 * @see {@link NotificationsClientResolvedConfig | config} for NotificationsClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>User does not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Unexpected error during processing of request.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Request references a resource which does not exist. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Request was denied due to request throttling. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>This exception is thrown when the notification event fails validation.</p>
 *
 * @throws {@link NotificationsServiceException}
 * <p>Base exception class for all service exceptions from Notifications service.</p>
 *
 * @public
 */
export declare class ListEventRulesCommand extends ListEventRulesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListEventRulesRequest;
            output: ListEventRulesResponse;
        };
        sdk: {
            input: ListEventRulesCommandInput;
            output: ListEventRulesCommandOutput;
        };
    };
}
