import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListNotificationEventsRequest, ListNotificationEventsResponse } from "../models/models_0";
import { NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../NotificationsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListNotificationEventsCommand}.
 */
export interface ListNotificationEventsCommandInput extends ListNotificationEventsRequest {
}
/**
 * @public
 *
 * The output of {@link ListNotificationEventsCommand}.
 */
export interface ListNotificationEventsCommandOutput extends ListNotificationEventsResponse, __MetadataBearer {
}
declare const ListNotificationEventsCommand_base: {
    new (input: ListNotificationEventsCommandInput): import("@smithy/smithy-client").CommandImpl<ListNotificationEventsCommandInput, ListNotificationEventsCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [ListNotificationEventsCommandInput]): import("@smithy/smithy-client").CommandImpl<ListNotificationEventsCommandInput, ListNotificationEventsCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a list of NotificationEvents according to specified filters, in reverse chronological order (newest first).</p>
 *          <important>
 *             <p>User Notifications stores notifications in the individual Regions you register as notification hubs and the Region of the source event rule. ListNotificationEvents only returns notifications stored in the same Region in which the action is called.
 * 	  User Notifications doesn't backfill notifications to new Regions selected as notification hubs. For this reason, we recommend that you make calls in your oldest registered notification hub.
 * 	  For more information, see <a href="https://docs.aws.amazon.com/notifications/latest/userguide/notification-hubs.html">Notification hubs</a> in the <i>AWS User Notifications User Guide</i>.</p>
 *          </important>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { NotificationsClient, ListNotificationEventsCommand } from "@aws-sdk/client-notifications"; // ES Modules import
 * // const { NotificationsClient, ListNotificationEventsCommand } = require("@aws-sdk/client-notifications"); // CommonJS import
 * const client = new NotificationsClient(config);
 * const input = { // ListNotificationEventsRequest
 *   startTime: new Date("TIMESTAMP"),
 *   endTime: new Date("TIMESTAMP"),
 *   locale: "STRING_VALUE",
 *   source: "STRING_VALUE",
 *   includeChildEvents: true || false,
 *   aggregateNotificationEventArn: "STRING_VALUE",
 *   maxResults: Number("int"),
 *   nextToken: "STRING_VALUE",
 * };
 * const command = new ListNotificationEventsCommand(input);
 * const response = await client.send(command);
 * // { // ListNotificationEventsResponse
 * //   nextToken: "STRING_VALUE",
 * //   notificationEvents: [ // NotificationEvents // required
 * //     { // NotificationEventOverview
 * //       arn: "STRING_VALUE", // required
 * //       notificationConfigurationArn: "STRING_VALUE", // required
 * //       relatedAccount: "STRING_VALUE", // required
 * //       creationTime: new Date("TIMESTAMP"), // required
 * //       notificationEvent: { // NotificationEventSummary
 * //         schemaVersion: "STRING_VALUE", // required
 * //         sourceEventMetadata: { // SourceEventMetadataSummary
 * //           eventOriginRegion: "STRING_VALUE",
 * //           source: "STRING_VALUE", // required
 * //           eventType: "STRING_VALUE", // required
 * //         },
 * //         messageComponents: { // MessageComponentsSummary
 * //           headline: "STRING_VALUE", // required
 * //         },
 * //         eventStatus: "STRING_VALUE", // required
 * //         notificationType: "STRING_VALUE", // required
 * //       },
 * //       aggregationEventType: "STRING_VALUE",
 * //       aggregateNotificationEventArn: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListNotificationEventsCommandInput - {@link ListNotificationEventsCommandInput}
 * @returns {@link ListNotificationEventsCommandOutput}
 * @see {@link ListNotificationEventsCommandInput} for command's `input` shape.
 * @see {@link ListNotificationEventsCommandOutput} for command's `response` shape.
 * @see {@link NotificationsClientResolvedConfig | config} for NotificationsClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>User does not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Unexpected error during processing of request.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Request was denied due to request throttling. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>This exception is thrown when the notification event fails validation.</p>
 *
 * @throws {@link NotificationsServiceException}
 * <p>Base exception class for all service exceptions from Notifications service.</p>
 *
 * @public
 */
export declare class ListNotificationEventsCommand extends ListNotificationEventsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListNotificationEventsRequest;
            output: ListNotificationEventsResponse;
        };
        sdk: {
            input: ListNotificationEventsCommandInput;
            output: ListNotificationEventsCommandOutput;
        };
    };
}
